# crfs

[![GitHub Actions](https://github.com/messense/crfs-rs/workflows/Python/badge.svg)](https://github.com/messense/crfs-rs/actions?query=workflow%3APython)
[![PyPI](https://img.shields.io/pypi/v/crfs.svg)](https://pypi.org/project/crfs)

Python wrapper of the [crfs-rs](https://github.com/messense/crfs-rs) Rust crate.

## Installation

```bash
pip install crfs
```

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](../LICENSE) file.
